==> eiffelstudio-18.07.10.1981.tar: F_code/C1/i124.c <==
/*
 * Code for class I18N_STRING_FORMATTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "i124.h"
#include <ctype.h>
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {I18N_STRING_FORMATTER}.default_create */
void F24_357 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("default_create", 23, Current, 0, 0, 371);
	RTHOOK(1);
	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_0_0_) = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '$';
	RTHOOK(2);
	RTEE;
}

/* {I18N_STRING_FORMATTER}.formatted_string */
EIF_REFERENCE F24_361 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_NATURAL_32 loc3 = (EIF_NATURAL_32) 0;
	EIF_NATURAL_32 loc4 = (EIF_NATURAL_32) 0;
	EIF_NATURAL_32 loc5 = (EIF_NATURAL_32) 0;
	EIF_INTEGER_32 loc6 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc7 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(8);
	RTLR(0,tr1);
	RTLR(1,Result);
	RTLR(2,arg1);
	RTLR(3,Current);
	RTLR(4,arg2);
	RTLR(5,loc8);
	RTLR(6,loc9);
	RTLR(7,loc10);
	RTLIU(8);
	
	RTEAA("formatted_string", 23, Current, 10, 2, 375);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1022, 0x00).id, 1022, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1018_8342(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	loc6 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6916[Dtype(arg1)-1020])(RTCW(arg1));
	RTHOOK(3);
	tc1 = *(EIF_CHARACTER_8 *)(Current+ _CHROFF_0_0_);
	loc5 = (EIF_NATURAL_32) tc1;
	RTHOOK(4);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(5);
	loc6 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6916[Dtype(arg1)-1020])(RTCW(arg1));
	for (;;) {
		RTHOOK(6);
		if ((EIF_BOOLEAN) (loc1 > loc6)) break;
		RTHOOK(7);
		loc3 = (FUNCTION_CAST(EIF_NATURAL_32, (EIF_REFERENCE, EIF_INTEGER_32)) R6879[Dtype(arg1)-1021])(RTCW(arg1), loc1);
		RTHOOK(8);
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L)) <= loc6) && (EIF_BOOLEAN)(loc3 == loc5))) {
			RTHOOK(9);
			loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L));
			RTHOOK(10);
			loc4 = (FUNCTION_CAST(EIF_NATURAL_32, (EIF_REFERENCE, EIF_INTEGER_32)) R6879[Dtype(arg1)-1021])(RTCW(arg1), loc2);
			RTHOOK(11);
			loc7 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
			for (;;) {
				RTHOOK(12);
				tb1 = '\01';
				tb2 = '\01';
				if (!(EIF_BOOLEAN) (loc2 > loc6)) {
					tr1 = RTLNS(eif_new_type(956, 0x00).id, 956, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_NATURAL_32 *)tr1 = loc4;
					tb3 = F955_7775(RTCW(tr1));
					tb2 = (EIF_BOOLEAN) !tb3;
				}
				if (!tb2) {
					tc1 = (EIF_CHARACTER_8) loc4;
					tb2 = EIF_TEST(isdigit(tc1));
					tb1 = (EIF_BOOLEAN) !tb2;
				}
				if (tb1) break;
				RTHOOK(13);
				tc1 = (EIF_CHARACTER_8) loc4;
				tr1 = c_outc(tc1);
				ti4_1 = F1018_8407(RTCW(tr1));
				loc7 = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 + (EIF_INTEGER_32) (loc7 * ((EIF_INTEGER_32) 10L)));
				RTHOOK(14);
				loc2++;
				RTHOOK(15);
				if ((EIF_BOOLEAN) (loc2 <= loc6)) {
					RTHOOK(16);
					loc4 = (FUNCTION_CAST(EIF_NATURAL_32, (EIF_REFERENCE, EIF_INTEGER_32)) R6879[Dtype(arg1)-1021])(RTCW(arg1), loc2);
				}
			}
			RTHOOK(17);
			if ((EIF_BOOLEAN) (loc7 > ((EIF_INTEGER_32) 0L))) {
				RTHOOK(18);
				tb2 = '\0';
				tb3 = F939_7190(RTCW(arg2), loc7);
				if (tb3) {
					tr1 = F939_7163(RTCW(arg2), loc7);
					loc8 = RTCCL(tr1);
					tb2 = EIF_TEST(loc8);
				}
				if (tb2) {
					RTHOOK(19);
					loc9 = RTCCL(loc8);
					loc9 = RTRV(eif_new_type(1017, 0x00),loc9);
					if (EIF_TEST(loc9)) {
						RTHOOK(20);
						F1023_8584(RTCW(Result), loc9);
					} else {
						RTHOOK(21);
						loc10 = RTCCL(loc8);
						loc10 = RTRV(eif_new_type(1017, 0x00),loc10);
						if (EIF_TEST(loc10)) {
							RTHOOK(22);
							tr1 = RTLNS(eif_new_type(1022, 0x00).id, 1022, _OBJSIZ_1_1_0_3_0_0_0_0_);
							F1021_8479(RTCW(tr1), loc10);
							F1023_8584(RTCW(Result), tr1);
						} else {
							RTHOOK(23);
							tr1 = RTCCL(loc8);
							tr1 = F24_364(Current, tr1);
							F1023_8584(RTCW(Result), tr1);
						}
					}
				} else {
					RTHOOK(24);
					tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R6957[Dtype(arg1)-1021])(RTCW(arg1), loc1, (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
					F1023_8584(RTCW(Result), tr1);
				}
				RTHOOK(25);
				loc1 = (EIF_INTEGER_32) loc2;
			} else {
				RTHOOK(26);
				F1020_8442(RTCW(Result), loc3);
				RTHOOK(27);
				loc1++;
			}
		} else {
			RTHOOK(28);
			F1020_8442(RTCW(Result), loc3);
			RTHOOK(29);
			loc1++;
		}
	}
	RTHOOK(30);
	RTLE;
	RTEE;
	return Result;
}

/* {I18N_STRING_FORMATTER}.out_from_separate_any */
EIF_REFERENCE F24_364 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,arg1);
	RTLR(2,tr2);
	RTLR(3,Result);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("out_from_separate_any", 23, Current, 0, 1, 378);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1025, 0x00).id, 1025, _OBJSIZ_1_1_0_3_0_0_0_0_);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R28[Dtype(arg1)-0])(RTCW(arg1));
	F1024_8643(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit24 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C1/i124.c <==
/*
 * Code for class I18N_STRING_FORMATTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "i124.h"
#include <ctype.h>
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {I18N_STRING_FORMATTER}.default_create */
void F24_357 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("default_create", 23, Current, 0, 0, 371);
	RTHOOK(1);
	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_0_0_) = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '$';
	RTHOOK(3);
	RTEE;
}

/* {I18N_STRING_FORMATTER}.formatted_string */
EIF_REFERENCE F24_361 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_NATURAL_32 loc3 = (EIF_NATURAL_32) 0;
	EIF_NATURAL_32 loc4 = (EIF_NATURAL_32) 0;
	EIF_NATURAL_32 loc5 = (EIF_NATURAL_32) 0;
	EIF_INTEGER_32 loc6 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc7 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(8);
	RTLR(0,Result);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,arg2);
	RTLR(5,loc8);
	RTLR(6,loc9);
	RTLR(7,loc10);
	RTLIU(8);
	
	RTEAA("formatted_string", 23, Current, 10, 2, 375);
	RTGC;
	RTHOOK(1);
	Result = RTLNS(eif_new_type(1029, 0x00).id, 1029, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1025_8435(RTCW(Result));
	RTHOOK(2);
	loc6 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6984[Dtype(RTCW(arg1))-1028])(arg1);
	RTHOOK(3);
	tc1 = *(EIF_CHARACTER_8 *)(Current+ _CHROFF_0_0_);
	loc5 = (EIF_NATURAL_32) tc1;
	RTHOOK(4);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(5);
	loc6 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6984[Dtype(RTCW(arg1))-1028])(arg1);
	for (;;) {
		RTHOOK(6);
		if ((EIF_BOOLEAN) (loc1 > loc6)) break;
		RTHOOK(7);
		loc3 = (FUNCTION_CAST(EIF_NATURAL_32, (EIF_REFERENCE, EIF_INTEGER_32)) R6947[Dtype(RTCW(arg1))-1028])(arg1, loc1);
		RTHOOK(8);
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L)) <= loc6) && (EIF_BOOLEAN)(loc3 == loc5))) {
			RTHOOK(9);
			loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L));
			RTHOOK(10);
			loc4 = (FUNCTION_CAST(EIF_NATURAL_32, (EIF_REFERENCE, EIF_INTEGER_32)) R6947[Dtype(RTCW(arg1))-1028])(arg1, loc2);
			RTHOOK(11);
			loc7 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
			for (;;) {
				RTHOOK(12);
				tb1 = '\01';
				tb2 = '\01';
				if (!(EIF_BOOLEAN) (loc2 > loc6)) {
					tr1 = RTLNS(eif_new_type(963, 0x00).id, 963, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_NATURAL_32 *)tr1 = loc4;
					tb3 = F962_7854(RTCW(tr1));
					tb2 = (EIF_BOOLEAN) !tb3;
				}
				if (!tb2) {
					tc1 = (EIF_CHARACTER_8) loc4;
					tb2 = EIF_TEST(isdigit(tc1));
					tb1 = (EIF_BOOLEAN) !tb2;
				}
				if (tb1) break;
				RTHOOK(13);
				tc1 = (EIF_CHARACTER_8) loc4;
				tr1 = c_outc(tc1);
				ti4_1 = F1025_8500(RTCW(tr1));
				loc7 = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 + (EIF_INTEGER_32) (loc7 * ((EIF_INTEGER_32) 10L)));
				RTHOOK(14);
				loc2++;
				RTHOOK(15);
				if ((EIF_BOOLEAN) (loc2 <= loc6)) {
					RTHOOK(16);
					loc4 = (FUNCTION_CAST(EIF_NATURAL_32, (EIF_REFERENCE, EIF_INTEGER_32)) R6947[Dtype(RTCW(arg1))-1028])(arg1, loc2);
				}
			}
			RTHOOK(17);
			if ((EIF_BOOLEAN) (loc7 > ((EIF_INTEGER_32) 0L))) {
				RTHOOK(18);
				tb2 = '\0';
				tb3 = F946_7269(RTCW(arg2), loc7);
				if (tb3) {
					tr1 = F946_7242(RTCW(arg2), loc7);
					loc8 = RTCCL(tr1);
					tb2 = EIF_TEST(loc8);
				}
				if (tb2) {
					RTHOOK(19);
					loc9 = RTCCL(loc8);
					loc9 = RTRV(eif_new_type(1024, 0x00),loc9);
					if (EIF_TEST(loc9)) {
						RTHOOK(20);
						F1030_8677(RTCW(Result), loc9);
					} else {
						RTHOOK(21);
						loc10 = RTCCL(loc8);
						loc10 = RTRV(eif_new_type(1024, 0x00),loc10);
						if (EIF_TEST(loc10)) {
							RTHOOK(22);
							tr1 = RTLNS(eif_new_type(1029, 0x00).id, 1029, _OBJSIZ_1_1_0_3_0_0_0_0_);
							F1028_8572(RTCW(tr1), loc10);
							F1030_8677(RTCW(Result), tr1);
						} else {
							RTHOOK(23);
							tr1 = RTCCL(loc8);
							tr1 = F24_364(Current, tr1);
							F1030_8677(RTCW(Result), tr1);
						}
					}
				} else {
					RTHOOK(24);
					tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R7025[Dtype(RTCW(arg1))-1028])(arg1, loc1, (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
					F1030_8677(RTCW(Result), tr1);
				}
				RTHOOK(25);
				loc1 = (EIF_INTEGER_32) loc2;
			} else {
				RTHOOK(26);
				F1027_8535(RTCW(Result), loc3);
				RTHOOK(27);
				loc1++;
			}
		} else {
			RTHOOK(28);
			F1027_8535(RTCW(Result), loc3);
			RTHOOK(29);
			loc1++;
		}
	}
	RTHOOK(31);
	RTLE;
	RTEE;
	return Result;
}

/* {I18N_STRING_FORMATTER}.out_from_separate_any */
EIF_REFERENCE F24_364 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("out_from_separate_any", 23, Current, 0, 1, 378);
	RTGC;
	RTHOOK(1);
	Result = RTLNS(eif_new_type(1032, 0x00).id, 1032, _OBJSIZ_1_1_0_3_0_0_0_0_);
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R28[Dtype(RTCW(arg1))-2])(arg1);
	F1031_8736(RTCW(Result), tr1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit24 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
